@@ -1,15 +1,23 @@
 from __future__ import annotations
 
 import os
+import sys
+import tempfile
 
 from pathlib import Path
 from stat import S_IREAD
+from typing import TYPE_CHECKING
 
 import pytest
 
+
+if TYPE_CHECKING:
+    from pytest_mock import MockerFixture
+
 from poetry.core.utils.helpers import combine_unicode
 from poetry.core.utils.helpers import parse_requires
 from poetry.core.utils.helpers import readme_content_type
+from poetry.core.utils.helpers import robust_rmtree
 from poetry.core.utils.helpers import temporary_directory
 
 
@@ -41,7 +49,7 @@ zipfile36>=0.1.0.0,<0.2.0.0
 
 [dev]
 isort@ git+git://github.com/timothycrosley/isort.git@e63ae06ec7d70b06df9e528357650281a3d3ec22#egg=isort
-"""
+"""  # noqa: E501
     result = parse_requires(requires)
     expected = [
         "jsonschema>=2.6.0.0,<3.0.0.0",
@@ -118,3 +126,60 @@ def test_utils_helpers_readme_content_type(
     readme: str | Path, content_type: str
 ) -> None:
     assert readme_content_type(readme) == content_type
+
+
+def test_temporary_directory_python_3_10_or_newer(mocker: MockerFixture) -> None:
+    mocked_rmtree = mocker.patch("shutil.rmtree")
+    mocked_temp_dir = mocker.patch("tempfile.TemporaryDirectory")
+    mocked_mkdtemp = mocker.patch("tempfile.mkdtemp")
+
+    mocker.patch.object(sys, "version_info", (3, 10))
+    with temporary_directory() as tmp:
+        assert tmp
+
+    assert not mocked_rmtree.called
+    assert not mocked_mkdtemp.called
+    mocked_temp_dir.assert_called_with(ignore_cleanup_errors=True)
+
+
+def test_temporary_directory_python_3_9_or_older(mocker: MockerFixture) -> None:
+    mocked_rmtree = mocker.patch("shutil.rmtree")
+    mocked_temp_dir = mocker.patch("tempfile.TemporaryDirectory")
+    mocked_mkdtemp = mocker.patch("tempfile.mkdtemp")
+
+    mocked_mkdtemp.return_value = "hello from test"
+
+    mocker.patch.object(sys, "version_info", (3, 9))
+    with temporary_directory() as tmp:
+        assert tmp == "hello from test"
+
+    assert mocked_rmtree.called
+    assert mocked_mkdtemp.called
+    assert not mocked_temp_dir.called
+
+
+def test_robust_rmtree(mocker: MockerFixture) -> None:
+    mocked_rmtree = mocker.patch("shutil.rmtree")
+
+    # this should work after an initial exception
+    name = tempfile.mkdtemp()
+    mocked_rmtree.side_effect = [
+        OSError(
+            "Couldn't delete file yet, waiting for references to clear", "mocked path"
+        ),
+        None,
+    ]
+    robust_rmtree(name)
+
+    # this should give up after retrying multiple times
+    mocked_rmtree.side_effect = OSError(
+        "Couldn't delete file yet, this error won't go away after first attempt"
+    )
+    with pytest.raises(OSError):
+        robust_rmtree(name, max_timeout=0.04)
+
+    # clear the side effect (breaks the tear-down otherwise)
+    mocker.stop(mocked_rmtree)
+    # use the real method to remove the temp folder we created for this test
+    robust_rmtree(name)
+    assert not Path(name).exists()
